[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg)](CODE_OF_CONDUCT.md)
[![PyPI badge](http://img.shields.io/pypi/v/esssans.svg)](https://pypi.python.org/pypi/esssans)
[![Anaconda-Server Badge](https://anaconda.org/scipp/esssans/badges/version.svg)](https://anaconda.org/scipp/esssans)
[![License: BSD 3-Clause](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](LICENSE)

# esssans

## About

SANS data reduction for the European Spallation Source

## Installation

```sh
python -m pip install esssans
```
